package OpenFrame;

use strict;
use warnings::register;

##
## we just want to track versions
##
our $VERSION = '2.02';

=head1 NAME

OpenFrame - An Application Framework for Perl and the Web

=head1 DESCRIPTION

OpenFrame is an Application Framework for Perl and the Web.  It is designed to
do enough to make your life easier, and provide enough flexibility to make
extending it to do what *you* want it to pretty easily.

Anyway, this is a pretty raw release.  It's ready to use, but it is still lacking
quite a lot of documentation.  Some of the SOAP stuff needs to be reexamined
and that will happen over the next few weeks as we need it.  Patches welcome.

Developers should read lib/OpenFrame/AppWrite.pod and lib/OpenFrame/Slots.pod,
installing-things type people should read lib/OpenFrame/Install.pod.

Regards,
James

=head1 AUTHOR

James A. Duncan <jduncan@fotango.com>

=head1 COPYRIGHT

Copyright (C) 2001, Fotango Ltd.

This module is free software; you can redistribute it or modify it
under the same terms as Perl itself.

=cut

1;
